<h1 align = "center">:rocket: Deep Dream :facepunch:</h1>

[![Downloads](http://pepy.tech/badge/DeepDream)](http://pepy.tech/project/DeepDream)
[![Downloads](https://pepy.tech/badge/DeepDream/month)](https://pepy.tech/project/DeepDream/month)
[![Downloads](https://pepy.tech/badge/DeepDream/week)](https://pepy.tech/project/DeepDream/week)
[![PyPI release](https://img.shields.io/pypi/v/DeepDream.svg)](https://pypi.python.org/pypi/DeepDream)
[![PyPI version](https://img.shields.io/pypi/pyversions/DeepDream.svg)](https://pypi.python.org/pypi/DeepDream)
---